<?php
/*
 * #? This file contains the admin panel options
*/

/**
 * Renders menu and proccess settings
 *
 * @package Wordpress
 * @since 1.0
 */
class SetingsRenderer{

	function __construct(){
		add_action('admin_menu', array($this, 'SettingsMenu') );
		add_action( 'admin_init', array($this, 'ErpAdminInit') );
		add_action('admin_enqueue_scripts', array($this, 'erp_jq_scripts') );
	}
	
	/**
	 * Registers options menu
	 *
	 * @package Wordpress
	 * @since 1.0
	 */
	function SettingsMenu() {
		add_options_page( 'Easy related posts configuration', 'Easy Related Posts', 'manage_options', 'easy_related_posts', array($this, 'OptPageRenderer') );
	}
	
	/**
	 * Registers options update function
	 *
	 * @package Wordpress
	 * @since 1.0
	 */
	function ErpAdminInit() {
		add_action( 'admin_post_save_erpOpts', array($this, 'OptsProcessing') );
	}
	
	/**
	 * Loads jquerry scripts
	 *
	 * @package Wordpress
	 * @since 1.0
	 */
	function erp_jq_scripts() {
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'jquery-ui-core' );
		wp_enqueue_script( 'jquery-effects-fade' );
		wp_enqueue_script( 'erpAdminScripts', plugins_url('/inc/js/adminScripts.js', __FILE__ ));
	}

	/**
	 * Renders given options as table elements. Html table opening and closing tags must be initialized outside function.
	 *
	 * @package WordPress
	 * @since 1.0
	 *
	 * @param string $optType Text, checkbox, etc
	 * @param string $optName Unique name
	 * @param string $optID Unique ID
	 * @param string $optValue Current value
	 * @param string $optMultiple Array with choises in case of multiple choises ('dropdown' or 'radio') or with html element atributes in other cases
	 * @return string
	 */
	function OptArrayRenderer($optType, $optName, $optID, $optMultiple = FALSE) {

		$opt = get_option( 'erpOpts' );

		if ($optType == 'checkbox') {
			if (is_array($optMultiple)) {
				$atrs = '';
				foreach ($optMultiple as $atr=>$value){
					$atrs .= ' ' . $atr . '="' . $value . '" ';
				}
			} else { $atrs = '';
			}
			$output = '<tr><td><label for="' . $optID . '">' . $optName . ' :' . '</label></td>';
			$output .= '<td><input class="erp-optchbx" id="' . $optID . '" name="' . $optID . '" type="' . $optType . '"' . 'value="' . $opt[$optID] .'" ' . $atrs . checked( $opt[$optID],'1', FALSE ) . '/></td></tr>';
		}
		elseif ($optType == 'text' || $optType == 'number') {
			if (is_array($optMultiple)) {
				$atrs = '';
				foreach ($optMultiple as $atr=>$value){
					$atrs .= ' ' . $atr . '="' . $value . '" ';
				}
			} else { $atrs = '';
			}
			$output = '<tr><td><label for="' . $optID . '">' . $optName . ' :' . '</label></td>';
			$output .= '<td><input class="erp-opttxt" id="' . $optID . '" name="' . $optID . '" type="' . $optType . '"' . $atrs . 'value="' . $opt[$optID] . '"/></td></tr>';
		}
		elseif ($optType == 'select' && is_array($optMultiple)){
			$id =$opt[$optID];
			$output = '<tr><td><label for="' . $optID . '">' . $optName . ' :' . '</td>';
			$output .= '<td><select class="erp-optsel" id="' . $optID . '" name="' . $optID . '">';
			foreach ($optMultiple as $key => $val){
				$valLow = strtolower(str_replace(' ',	'_', $val) );
				$output .= '<option value="' . $valLow . '"' . selected( $id, $valLow, FALSE ) . '>' . $val . '</option>';
			}
			$output .= '</select></td></tr></label>';
		}
		elseif ($optType == 'radio' && is_array($optMultiple)){
			$output = '<tr><td><label for="' . $optID . '">' . $optName . ' :' . '</label></td><td></td></tr>';
			foreach ($optMultiple as $val){
				$valLow = strtolower(str_replace(' ',	'_', $val) );
				$output .= '<tr><td></td><td><input type="' . $optType . '" name="' . $val . '" value="' . checked( $opt[$optID], $val, FALSE ) . '"/></td></tr>';
			}
		}
		return $output;
	}

	/**
	 * Renders the settings page
	 *
	 * @package Wordpress
	 * @since 1.0
	 */
	function OptPageRenderer() {

		$opt = get_option( 'erpOpts' );

		$opt['titletd'] = isset($opt['titletd']) ? $opt['titletd'] : 'Easy related posts';
		$opt['activate_plugin'] = isset($opt['activate_plugin']) ? $opt['activate_plugin'] : 1;
		$opt['num_of_p_t_dspl'] = isset($opt['num_of_p_t_dspl']) ? $opt['num_of_p_t_dspl'] : 5;
		/* #? FIXME Right now it seems there is a problem when getting the excerpt with get_the_excerpt() or any related func */
		$opt['erpcontent'] = isset($opt['erpcontent']) ? $opt['erpcontent'] : 'post_title';
		$opt['exc_len'] = isset($opt['exc_len']) ? $opt['exc_len'] : 15 ;
		$opt['ttl_sz'] = isset($opt['ttl_sz']) ? $opt['ttl_sz'] : 0 ;
		$opt['exc_sz'] = isset($opt['exc_sz']) ? $opt['exc_sz'] : 0 ;
		$opt['more_txt'] = isset($opt['more_txt']) ? $opt['more_txt'] : ' ...read more' ;
		$opt['num_of_p_p_row'] = isset($opt['num_of_p_p_row']) ? $opt['num_of_p_p_row'] : 3;
		$opt['display_layout'] = isset($opt['display_layout']) ? $opt['display_layout'] : '1_post_per_row';
		$opt['display_thumbnail'] = isset($opt['display_thumbnail']) ? $opt['display_thumbnail'] : 1;
		$opt['crop_thumbnail'] = isset($opt['crop_thumbnail']) ? $opt['crop_thumbnail'] : 1;
		$opt['thumbnail_height'] = isset($opt['thumbnail_height']) ? $opt['thumbnail_height'] : 150;
		$opt['thumbnail_width'] = isset($opt['thumbnail_width']) ? $opt['thumbnail_width'] : '500';

		update_option('erpOpts', $opt);
		// TODO Make the settings for new appearance
		?>
<div id="erp-opt-general" class="wrap">
	<h2>Easy Related Posts Settings</h2>
	<form method="post" action="admin-post.php">
		<input type="hidden" name="action" value="save_erpOpts" />
		<?php echo wp_nonce_field( 'erpoptnonce' );?>
		
		<table class="gen-opt-table">
		<tr><th colspan="2">General Options</th></tr>
			<?php 
			echo $this->OptArrayRenderer('checkbox', 'Activate plugin', 'activate_plugin');
			echo $this->OptArrayRenderer('text', 'Title to display', 'titletd');
			?>
		</table>
		
		<table class="con-opt-table">
		<tr><th colspan="2">Content Options</th></tr>
			<?php
			echo $this->OptArrayRenderer('number', 'Number of posts to display', 'num_of_p_t_dspl', array('size'=>'2pt'));
			/* #? FIXME Right now it seems there is a problem when getting the excerpt with get_the_excerpt() or any related func */
			echo $this->OptArrayRenderer('select', 'Content', 'erpcontent', array('Post title', 'Title + excerpt'));
			echo $this->OptArrayRenderer('number', 'Post title size (px)', 'ttl_sz', array('size'=>'2pt'));
			echo $this->OptArrayRenderer('number', 'Post excerpt size (px)', 'exc_sz', array('size'=>'2pt'));
			echo $this->OptArrayRenderer('number', 'Excerpt length (words)', 'exc_len', array('size'=>'2pt'));
			echo $this->OptArrayRenderer('text', 'Read more text', 'more_txt');
			?>
		</table>

		<table class="lay-opt-table" >
		<tr><th colspan="2">Layout Options</th></tr>
			<?php
			echo $this->OptArrayRenderer('checkbox', 'Display thumbnail', 'display_thumbnail');
			echo $this->OptArrayRenderer('checkbox', 'Crop thumbnail', 'crop_thumbnail' );
			echo $this->OptArrayRenderer('number', 'Thumbnail height', 'thumbnail_height', array('size'=>'2pt'));
			echo $this->OptArrayRenderer('number', 'Thumbnail width (optional)', 'thumbnail_width', array('size'=>'2pt'));
			echo $this->OptArrayRenderer('select', 'Display layout', 'display_layout', array('1 post per row', 'define bellow', 'pop up block'));
			echo $this->OptArrayRenderer('number', 'Number of posts per row', 'num_of_p_p_row', array('size'=>'2pt'));
			?>
		</table>
		<?php 
		echo get_submit_button('Update options', 'primary large','Save');
		?>
		<script type="text/javascript">
		checkThumbOptions = new ChkObj('#display_thumbnail', '#crop_thumbnail');
		checkCrop = new ChkObj('#crop_thumbnail', '#thumbnail_height, #thumbnail_width');
		checkContent = new ChkObj('#erpcontent', '#exc_len, #exc_sz');
		checkPostsPerRow = new ChkObj('#display_layout', '#num_of_p_p_row');

		checkThumbOptions.checkBoxChecker();
		checkCrop.checkBoxChecker();
		checkContent.selectionChecker(['post_title']);
		checkPostsPerRow.selectionChecker(['1_post_per_row']);

		jQuery(document).ready(function() {
			jQuery('#display_thumbnail').click(function() {
				checkThumbOptions.checkBoxChecker();
				checkCrop.checkBoxChecker();
			});
			jQuery('#crop_thumbnail').click(function() {
				checkCrop.checkBoxChecker();
			});
			jQuery('#erpcontent').change(function() {
				checkContent.selectionChecker(['post_title']);
			});
			jQuery('#display_layout').change(function() {
				checkPostsPerRow.selectionChecker(['1_post_per_row']);
			});
		});
		</script>
	</form>
</div>
<?php 		

	}


	/**
	 * Process updated settings to be saved in options array
	 *
	 * @package Wordpress
	 * @since 1.0
	 */
	function OptsProcessing() {

		if ( !current_user_can( 'manage_options' ) ){
			wp_die( 'Not allowed' );
		}

		// #? Check this comes from admin panel
		check_admin_referer('erpoptnonce');

		$newOpt = get_option( 'erpOpts' );
		/* #? Fill options not included in admin panel */
		$newOpt = $oldOpt;

			$newOpt['titletd'] = isset($_POST['titletd']) ? strip_tags( $_POST['titletd']) : $options['titletd'];
			$newOpt['activate_plugin'] = isset($_POST['activate_plugin']) ? (bool) 1 : 0;
			$newOpt['num_of_p_t_dspl'] = isset($_POST['num_of_p_t_dspl']) ? (int) $_POST['num_of_p_t_dspl'] : $options['num_of_p_t_dspl'];
			$newOpt['erpcontent'] = isset($_POST['erpcontent']) ? strip_tags( $_POST['erpcontent']) : $options['erpcontent'];
			$newOpt['exc_len'] = isset($_POST['exc_len']) ? (int) $_POST['exc_len'] : $options['exc_len'];
			$newOpt['exc_sz'] = isset($_POST['exc_sz']) ? (int) $_POST['exc_sz'] : $options['exc_sz'];
			$newOpt['ttl_sz'] = isset($_POST['ttl_sz']) ? (int) $_POST['ttl_sz'] : $options['ttl_sz'];
			$newOpt['more_txt'] = isset($_POST['more_txt']) ? strip_tags( $_POST['more_txt']) : $options['more_txt'];
			$newOpt['num_of_p_p_row'] = isset($_POST['num_of_p_p_row']) ? (int) $_POST['num_of_p_p_row'] : $options['num_of_p_p_row'];
			$newOpt['display_layout'] = isset($_POST['display_layout']) ? strip_tags( $_POST['display_layout'] ) : $options['display_layout'];
			$newOpt['display_thumbnail'] = isset($_POST['display_thumbnail']) ? (bool) 1 : 0;
			$newOpt['crop_thumbnail'] = isset($_POST['crop_thumbnail']) ? (bool) 1 : 0;
			$newOpt['thumbnail_height'] = isset($_POST['thumbnail_height']) ? (int) $_POST['thumbnail_height'] : $options['thumbnail_height'];
			$newOpt['thumbnail_width'] = isset($_POST['thumbnail_width']) ? (int) $_POST['thumbnail_width'] : $options['thumbnail_width'];


		update_option( 'erpOpts', $newOpt );


		wp_redirect( add_query_arg( 'page', 'easy_related_posts', admin_url( 'options-general.php' ) ) );

		exit;
	}
} // setingsRenderer
?>